Updaters
========

.. automodule:: stonesoup.updater
    :no-members:

.. automodule:: stonesoup.updater.base
    :show-inheritance:

Kalman
------

.. automodule:: stonesoup.updater.kalman
    :show-inheritance:

Particle
--------

.. automodule:: stonesoup.updater.particle
    :show-inheritance:

Ensemble
--------

.. automodule:: stonesoup.updater.ensemble
    :show-inheritance:

Information
-----------

.. automodule:: stonesoup.updater.information
    :show-inheritance:

Accumulated State Densities
---------------------------

.. automodule:: stonesoup.updater.asd
    :show-inheritance:

Point Process
-------------

.. automodule:: stonesoup.updater.pointprocess
    :show-inheritance:

AlphaBeta
---------

.. automodule:: stonesoup.updater.alphabeta
    :show-inheritance:

Sliding Innovation Filter
-------------------------

.. automodule:: stonesoup.updater.slidinginnovation
    :show-inheritance:

Categorical
-----------

.. automodule:: stonesoup.updater.categorical
    :show-inheritance:

Composite
-----------

.. automodule:: stonesoup.updater.composite
    :show-inheritance:

Chernoff
--------

.. automodule:: stonesoup.updater.chernoff
    :show-inheritance:
